==> usrp-0.4.tar.gz: usrp-0.4/firmware/include/fpga_regs.h <==
/* -*- c++ -*- */
/*
 * Copyright 2003,2004 Free Software Foundation, Inc.
 * 
 * This file is part of GNU Radio
 * 
 * GNU Radio is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 * 
 * GNU Radio is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with GNU Radio; see the file COPYING.	If not, write to
 * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef _FPGA_REGS_H_
#define _FPGA_REGS_H_

// This mapping is really defined in control_bus.v
// Keep these in sync.

#define FR_RX_FREQ_0		 0
#define FR_RX_FREQ_1		 1
#define FR_RX_FREQ_2		 2
#define FR_RX_FREQ_3		 3
#define FR_TX_FREQ_0		 4
#define FR_TX_FREQ_1		 5
#define FR_TX_FREQ_2		 6
#define FR_TX_FREQ_3		 7

// DDC / DUC

#define	FR_INTERP_RATE		 8	// [1,255]
#define	FR_DECIM_RATE		 9	// [1,255]

// The FPGA needs to know the rate that samples are coming from and
// going to the A/D's and D/A's.  div = 128e6 / sample_rate

#define	FR_TX_SAMPLE_RATE_DIV	10
#define	FR_RX_SAMPLE_RATE_DIV	11


// offset corrections for ADC's and DAC's (2's complement)

#define	FR_ADC_OFFSET_3_2	12	// hi 16: ADC3, lo 16: ADC2
#define	FR_ADC_OFFSET_1_0	13
#define	FR_DAC_OFFSET_3_2	14
#define	FR_DAC_OFFSET_1_0	15

#define	FR_MASTER_CTRL		16	// master enable and reset controls
#  define  bmFR_MC_ENABLE_TX		(1 << 0)
#  define  bmFR_MC_ENABLE_RX		(1 << 1)
#  define  bmFR_MC_RESET_TX		(1 << 2)
#  define  bmFR_MC_RESET_RX		(1 << 3)

// i/o direction registers for pins that go to daughterboards.
// Setting the bit makes it an output.
// top 16 is mask, low 16 is value

#define	FR_OE_0			17	// slot 0
#define	FR_OE_1			18
#define	FR_OE_2			19
#define	FR_OE_3			20

// i/o registers for pins that go to daughterboards.
// top 16 is a mask, low 16 is value

#define	FR_IO_0			21	// slot 0
#define	FR_IO_1			22
#define	FR_IO_2			23
#define	FR_IO_3			24


#endif /* _FPGA_REGS_H_ */

==> usrp-0.5.tar.gz: usrp-0.5/firmware/include/fpga_regs.h <==
/* -*- c++ -*- */
/*
 * Copyright 2003,2004 Free Software Foundation, Inc.
 * 
 * This file is part of GNU Radio
 * 
 * GNU Radio is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 * 
 * GNU Radio is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with GNU Radio; see the file COPYING.	If not, write to
 * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef _FPGA_REGS_H_
#define _FPGA_REGS_H_

// This mapping is really defined in control_bus.v
// Keep these in sync.

#define FR_RX_FREQ_0		 0
#define FR_RX_FREQ_1		 1
#define FR_RX_FREQ_2		 2
#define FR_RX_FREQ_3		 3
#define FR_TX_FREQ_0		 4
#define FR_TX_FREQ_1		 5
#define FR_TX_FREQ_2		 6
#define FR_TX_FREQ_3		 7

// DDC / DUC

#define	FR_INTERP_RATE		 8	// [1,255]
#define	FR_DECIM_RATE		 9	// [1,255]

// The FPGA needs to know the rate that samples are coming from and
// going to the A/D's and D/A's.  div = 128e6 / sample_rate

#define	FR_TX_SAMPLE_RATE_DIV	10
#define	FR_RX_SAMPLE_RATE_DIV	11


// offset corrections for ADC's and DAC's (2's complement)

#define	FR_ADC_OFFSET_3_2	12	// hi 16: ADC3, lo 16: ADC2
#define	FR_ADC_OFFSET_1_0	13
#define	FR_DAC_OFFSET_3_2	14
#define	FR_DAC_OFFSET_1_0	15

#define	FR_MASTER_CTRL		16	// master enable and reset controls
#  define  bmFR_MC_ENABLE_TX		(1 << 0)
#  define  bmFR_MC_ENABLE_RX		(1 << 1)
#  define  bmFR_MC_RESET_TX		(1 << 2)
#  define  bmFR_MC_RESET_RX		(1 << 3)

// i/o direction registers for pins that go to daughterboards.
// Setting the bit makes it an output.
// top 16 is mask, low 16 is value

#define	FR_OE_0			17	// slot 0
#define	FR_OE_1			18
#define	FR_OE_2			19
#define	FR_OE_3			20

// i/o registers for pins that go to daughterboards.
// top 16 is a mask, low 16 is value

#define	FR_IO_0			21	// slot 0
#define	FR_IO_1			22
#define	FR_IO_2			23
#define	FR_IO_3			24

#define	FR_MODE			25
#  define  bmFR_MODE_NORMAL		      0
#  define  bmFR_MODE_LOOPBACK		(1 << 0)	// enable digital loopback
#  define  bmFR_MODE_RX_COUNTING	(1 << 1)	// Rx is counting

#endif /* _FPGA_REGS_H_ */
